Learn R Programming

nadiv (version 2.14.2)

makeA: Creates the additive genetic relationship matrix

Description

This returns the additive relationship matrix in sparse matrix format.

Usage

makeA(pedigree)

Arguments

pedigree
A pedigree where the columns are ordered ID, Dam, Sire

Value

  • Returns A, or the numerator relationship matrix, in sparse matrix form.

Details

Missing parents (e.g., base population) should be denoted by either 'NA', '0', or '*'.

Used as a support function to makeD.

See function makeAinv for directly obtaining the inverse of the additive genetic relationship matrix.

See Also

makeD, makeS

Examples

Run this code
makeA(Mrode2)

Run the code above in your browser using DataLab