nadiv-package: (Non)Additive Genetic Relatedness Matrices in Animal Model Analyses
Description
Constructs (non)additive genetic relationship matrices, and their inverses, from a pedigree to be used in linear mixed effect models (A.K.A. the 'animal model'). Also includes other functions to facilitate the use of animal models. Some functions have been created to be used in conjunction with the R package for 'ASReml' software, which can be obtained upon purchase from 'VSN' international (http://www.vsni.co.uk/software/asreml).Details
ll{
Package: nadiv
Type: Package
Version: 2.14.2
Date: 2016-02-04
URL: http://github.com/matthewwolak/nadiv
BugReports: http://github.com/matthewwolak/nadiv/issues
License: GPL (>=2)
LazyLoad: yes
}