Rdocumentation
powered by
Learn R Programming
nadiv (version 2.14.2)
Mrode3: Pedigree, from chapter 3 of Mrode (2005)
Description
An example pedigree with genetic groups and a data column
Usage
data(Mrode3)
Arguments
source
Mrode, R.A. 2005. Linear Models for the Prediction of Animal Breeding Values, 2nd ed. Cambridge, MA: CABI Publishing.