Calculates AIC/AICc values, AIC differences, Likelihood of models, and model probabilities.
Usage
aic(logLik, fp, n = NULL)
Arguments
logLik
A vector of model log-Likelihoods
fp
A vector containing the numbers of free parameters of each model included in the logLik vector
n
An optional vector of sample sizes for each model. Used to calculate AICc (small sample un-biased AIC).
Value
AICvector containing AIC/AICc (depending on value of n
delta_AICvector containing AIC differences from the minimum AIC(c)
AIClikvector containing likelihoods for each model, given the data. Represents the relative strength of evidence for each model.
wAkaike weights.
Details
Calculations and notation follows chapter 2 of Burnham and Anderson (2002).
References
Burnham, K.P. and D.R. Anderson. 2002. Model Selection and Multimodel Inference. A Practical Information-Theoretic Approach, 2nd edn. Springer, New York.